@@ -2,11 +2,11 @@ from dataclasses import dataclass, field
 from pathlib import Path
 
 import yaml
+from rich.pretty import pprint
 
 from fluxvault.fs import ConcreteFsEntry, FsEntryStateManager, FsStateManager, FsType
-from fluxvault.helpers import RemoteStateDirective, AppMode, SyncStrategy
+from fluxvault.helpers import AppMode, RemoteStateDirective, SyncStrategy
 from fluxvault.log import log
-from rich.pretty import pprint
 
 
 @dataclass
